@@ -81,6 +81,10 @@ class Microservice(core.Construct):
 
         main_component_name (str): This is just a metadata. Textually specify the component the EC2 instance will host (e.g. tomcat, drupal, ...)
 
+        autoscaling_group_min_size (str): Optional - Auto Scaling group minimum size. Automatically set 2 is stack is Higly Available, 1 otherwise
+
+        autoscaling_group_max_size (str): Optional - Auto Scaling group maximym size. Automatically set 4 is stack is Higly Available, 1 otherwise
+
         s3_assets_bucket_name (str): S3 bucket name used to store the assets of the application
 
         s3_code_bucket_name (str): S3 bucket name used to store the code of the application
@@ -452,7 +456,8 @@ class Microservice(core.Construct):
                 "103.21.244.0/22",
                 "103.22.200.0/22",
                 "103.31.4.0/22",
-                "104.16.0.0/12",
+                "104.16.0.0/13", 
+                "104.24.0.0/14",
                 "108.162.192.0/18",
                 "131.0.72.0/22",
                 "141.101.64.0/18",
@@ -636,6 +641,7 @@ class Microservice(core.Construct):
         ec2_ami_id=None,
         ec2_instance_type=None,
         autoscaling_group_max_size=None,
+        autoscaling_group_min_size=None,
         s3_code_bucket_name=None,
         s3_assets_bucket_name=None,
         traffic_port=None,
@@ -703,7 +709,7 @@ class Microservice(core.Construct):
         is_private = not is_public
 
         is_production = environment == "Production"
-        is_not_producution = not is_production
+        is_not_production = not is_production
 
         has_upstream = not not upstream_security_group
         has_not_upstream = not has_upstream
@@ -716,6 +722,7 @@ class Microservice(core.Construct):
         is_public_and_has_upstream = is_public and has_upstream
         is_public_and_no_upstream_and_no_cdn = is_public and has_not_upstream and not_use_cdn
         is_private_and_is_https = is_private and is_https
+        is_private_and_has_upstream = is_private and has_upstream
         is_public_has_no_upstream_and_is_https = (
             has_not_upstream and is_public and is_https
         )
@@ -861,8 +868,8 @@ class Microservice(core.Construct):
                 snapshot_id=ebs_snapshot_id,
             )
 
-            if is_production:
-                ebs.add_override("DeletionPolicy", core.RemovalPolicy.RETAIN)
+            # if is_production:
+            #     ebs.add_override("DeletionPolicy", core.RemovalPolicy.SNAPSHOT)
 
         # ~~~~~~~~~~~~~~~~
         # Target group
@@ -932,6 +939,20 @@ class Microservice(core.Construct):
                     description="Upstream to HTTPS",
                 )
 
+            if is_private_and_has_upstream:
+                self.alb_security_group.add_ingress_rule(
+                    peer=upstream_security_group_as_peer,
+                    connection=self._tcp_connection_traffic_port,
+                    description="From upstream",
+                )
+
+            if is_not_production:
+                self.alb_security_group.add_ingress_rule(
+                    peer=_ec2.Peer.ipv4("168.202.4.57/32"),
+                    connection=self._tcp_connection_traffic_port,
+                    description="From Security Scan tool",
+                )
+
         # ~~~~~~~~~~~~~~~~
         # Elastic Load Balancer v2
         # ~~~~~~~~~~~~~~~~
@@ -1329,7 +1350,10 @@ class Microservice(core.Construct):
                 ],
                 wait_on_resource_signals=is_ha,
             )
-    
+
+        min_capacity = int(autoscaling_group_min_size) if autoscaling_group_min_size else 2 if is_ha else 1
+        max_capacity = int(autoscaling_group_max_size) if autoscaling_group_max_size else 4 if is_ha else 1
+        
         asg = _asg.AutoScalingGroup(
             self,
             self.asg_name(),
@@ -1338,8 +1362,8 @@ class Microservice(core.Construct):
             vpc=self._vpc,
             vpc_subnets=vpc_subnets if create_ebs else None,
             cooldown=core.Duration.seconds(120),
-            min_capacity=2 if is_ha else 1,
-            max_capacity=int(autoscaling_group_max_size),
+            min_capacity=min_capacity,
+            max_capacity=max_capacity,
             allow_all_outbound=True,
             health_check=_asg.HealthCheck.elb(grace=core.Duration.minutes(10)),
             ignore_unmodified_size_properties=True,
@@ -1365,7 +1389,7 @@ class Microservice(core.Construct):
         )
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Scheduler tags
-        if is_not_producution:
+        if is_not_production:
             ASG = asg.node.find_child("ASG")
             if tag_scheduler_uptime_skip:
                 Tags.of(ASG).add("SchedulerSkip", tag_scheduler_uptime_skip, apply_to_launched_instances=True,)
