@@ -1,5 +1,6 @@
 from aws_cdk import core, aws_iam as _iam
 from aws_cdk.core import Tags
+from aws_cdk_constructs.utils import normalize_environment_parameter
 
 class ServiceUserForIAC(core.Construct):
     """Construct to create the Service User to deploy a stack from a CD/CI pipeline
@@ -39,6 +40,7 @@ class ServiceUserForIAC(core.Construct):
         **kwargs
     ) -> None:
         super().__init__(scope, id, **kwargs)
+        environment = normalize_environment_parameter(environment)
 
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
@@ -115,6 +117,7 @@ class ServiceUserForIAC(core.Construct):
                         "iam:PassRole",
                         "iam:DeleteAccessKey",
                         "rds:DescribeEngineDefaultParameters",
+                        "rds:DescribeEvents",
                         "elasticfilesystem:*MountTarget*",
                         "elasticfilesystem:DescribeMountTargets",
                         "elasticfilesystem:DescribeFileSystems",
